@@ -1,23 +1,26 @@
 # SPDX-FileCopyrightText: Copyright (c) 2023 Jose D. Montoya
 #
-# SPDX-License-Identifier: Unlicense
+# SPDX-License-Identifier: MIT
 
 import time
 import board
 from ulab import numpy as np
 from circuitpython_uplot.uplot import Uplot
+from circuitpython_uplot.ucartesian import ucartesian
 
+# Setting up the display
 display = board.DISPLAY
+
+# Adding the plot area
 plot = Uplot(0, 0, display.width, display.height)
 
-
+# Creating some points to graph
 x = np.linspace(-4, 4, num=25)
-
 constant = 1.0 / np.sqrt(2 * np.pi)
 y = constant * np.exp((-(x**2)) / 2.0)
 
-
-plot.draw_plot(x, y)
+# Drawing the graph
+ucartesian(plot, x, y)
 
 display.show(plot)
 while True:
