@@ -17,7 +17,7 @@ display = board.DISPLAY
 plot = Uplot(0, 0, display.width, display.height)
 
 # Setting up tick parameters
-plot.tick_params(tickheight=12, tickcolor=0xFF0008, tickgrid=True)
+plot.tick_params(tickx_height=12, ticky_height=12, tickcolor=0xFF0008, tickgrid=True)
 plot.axs_params(axstype="cartesian")
 a = np.linspace(1, 100)
 b = [choice(a) for _ in a]
